import logging


def setup_test_logging():
    print("Setting up variety logger")
    logger = logging.getLogger("variety")
    logger.setLevel(logging.DEBUG)
    ch = logging.StreamHandler()
    ch.setLevel(logging.DEBUG)
    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
    ch.setFormatter(formatter)
    logger.addHandler(ch)



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os
import os.path
import time
import unittest

from variety.Util import Util, cache, debounce, throttle


class TestUtil(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        # Chdir to the tests directory so that we can find our test images
        curdir = os.path.dirname(os.path.abspath(__file__))
        if curdir:
            os.chdir(curdir)

    def test_sanitize_filename(self):
        self.assertEqual("i_m____g_.jpg", Util.sanitize_filename("i?m?*%^g_.jpg"))

    def test_get_local_name(self):
        self.assertEqual("img.jpg", Util.get_local_name("http://example.com/a/img?a=b"))
        self.assertEqual("img.jpg", Util.get_local_name("http://example.com/a/img.jpg?a=b"))
        self.assertEqual("img.jpg", Util.get_local_name("http://example.com/a/img.jpg#x"))
        self.assertEqual("img.jpg", Util.get_local_name("http://example.com/a/img.jpg?a=b#x"))
        self.assertEqual("im g.jpg", Util.get_local_name("http://example.com/a/im%20g.jpg?a=b#x"))
        self.assertEqual("im_g.jpg", Util.get_local_name("http://example.com/a/im%22g.jpg?a=b#x"))

        self.assertTrue(len(Util.get_local_name("a" * 1000 + ".jpg")) < 255)

    def test_split(self):
        self.assertEqual(["a", "b", "c", "d", "e"], Util.split("a\nb,c ,,d\n   e"))

    def test_metadata(self):
        self.assertTrue(os.path.exists("test.jpg"))
        info = {
            "sourceURL": "b",
            "imageURL": "d",
            "sourceName": "a",
            "sourceLocation": "c",
            "sourceType": "flickr",
            "author": "автор",
            "authorURL": "url",
            "keywords": ["дума1", "дума2"],
            "headline": "проба1 проба1",
            "description": "проба2 проба2",
            "sfwRating": 50,
            "extraData": {"key1": "val1", "key2": "val2"},
        }
        self.assertEqual(info, Util.read_metadata("test.jpg"))
        self.assertTrue(Util.write_metadata("test.jpg", info))
        self.assertEqual(info, Util.read_metadata("test.jpg"))

        self.assertTrue(os.path.exists("test.svg"))
        self.assertEqual(info, Util.read_metadata("test.svg"))
        Util.write_metadata("test.svg", info)
        self.assertEqual(info, Util.read_metadata("test.svg"))

    def test_read_write_rating(self):
        self.assertTrue(os.path.exists("test.jpg"))
        self.assertEqual(None, Util.get_rating("test.jpg"))

        Util.set_rating("test.jpg", None)
        self.assertEqual(None, Util.get_rating("test.jpg"))

        Util.set_rating("test.jpg", 4)
        self.assertEqual(4, Util.get_rating("test.jpg"))

        Util.set_rating("test.jpg", -1)
        self.assertEqual(-1, Util.get_rating("test.jpg"))

        Util.set_rating("test.jpg", 0)
        self.assertEqual(0, Util.get_rating("test.jpg"))

        Util.set_rating("test.jpg", None)
        self.assertEqual(None, Util.get_rating("test.jpg"))

        try:
            Util.set_rating("test.jpg", -10)
            self.assertTrue(False, "Exception expected")
        except ValueError:
            pass  # OK

    def test_find_unique_name(self):
        self.assertEqual("/etc/fstab_1", Util.find_unique_name("/etc/fstab"))
        self.assertEqual("/etc/bash_1.bashrc", Util.find_unique_name("/etc/bash.bashrc"))

    def test_folderpath(self):
        self.assertEqual("/", Util.folderpath("/"))
        self.assertEqual("/a/b/c/", Util.folderpath("/a/b/c"))

    def test_gtk_to_fcmatch_font(self):
        self.assertEqual(
            ("Bitstream Charter:Bold:Italic:10", "10"),
            Util.gtk_to_fcmatch_font("Bitstream Charter Bold Italic 10"),
        )

    def test_file_in(self):
        self.assertTrue(Util.file_in("/a/b/a.txt", "/a/"))
        self.assertTrue(Util.file_in("/a/b/a.txt", "/a/b/"))
        self.assertFalse(Util.file_in("/a/b/a.txt", "/c/"))

    def test_same_file_paths(self):
        self.assertTrue(Util.same_file_paths("/a/../b/c", "/b/c"))
        self.assertFalse(Util.same_file_paths("/a/../b/c", "/a/./b/c"))

    def test_compare_versions(self):
        self.assertEqual(-1, Util.compare_versions("0.6.9", "0.7.0-alpha1"))
        self.assertEqual(-1, Util.compare_versions("0.4.10", "0.4.11"))
        self.assertEqual(-1, Util.compare_versions("0.4.10", "0.5"))
        self.assertEqual(-1, Util.compare_versions("0.4.10", "1"))
        self.assertEqual(0, Util.compare_versions("0.4.10", "0.4.10"))
        self.assertEqual(0, Util.compare_versions("1.0.0", "1.0"))  # PEP 440 details
        self.assertEqual(1, Util.compare_versions("0.4.10", "0.4.8"))
        self.assertEqual(1, Util.compare_versions("0.4.10", "0.4"))
        self.assertEqual(1, Util.compare_versions("0.4.10", "0"))
        self.assertEqual(1, Util.compare_versions("0.7.0-beta1", "0.7.0-alpha1"))
        self.assertEqual(1, Util.compare_versions("0.7.0", "0.7.0-alpha1"))
        self.assertEqual(1, Util.compare_versions("0.7.0", "0.7.0-beta1"))

    def test_md5(self):
        self.assertEqual("098f6bcd4621d373cade4e832627b4f6", Util.md5("test"))

    def test_md5file(self):
        self.assertEqual("6af710446c1554d7bc79d7939d6900e4", Util.md5file("test.jpg"))

    def test_collapseuser(self):
        self.assertEqual(
            "~/.config/variety", Util.collapseuser("%s/.config/variety" % os.path.expanduser("~"))
        )
        self.assertEqual(
            "/home/peteraaa/.config/variety", Util.collapseuser("/home/peteraaa/.config/variety")
        )
        self.assertEqual("/media/.config/variety", Util.collapseuser("/media/.config/variety"))

    def test_random_hash(self):
        s = set(Util.random_hash() for i in range(100))
        self.assertEqual(100, len(s))
        for x in s:
            self.assertEqual(32, len(x))

    def test_get_file_icon_name(self):
        self.assertEqual("folder", Util.get_file_icon_name("/xxx/yyy/zzz"))  # nonexistent
        self.assertEqual("user-home", Util.get_file_icon_name("~"))
        # Icon name depends on desktop environment - accept both specific and generic
        icon_name = Util.get_file_icon_name("~/Pictures")
        self.assertIn(icon_name, ["folder-pictures", "folder"])

    def test_get_xdg_pictures_folder(self):
        self.assertEqual(os.path.expanduser("~/Pictures"), Util.get_xdg_pictures_folder())

    def test_safe_map(self):
        def f(i):
            if i <= 10:
                raise Exception
            return i

        self.assertEqual([20, 30], list(Util.safe_map(f, [1, 5, 20, 10, 30, 4])))

    @unittest.skipIf(os.getenv("SKIP_DOWNLOADER_TESTS"), "Skipping networked tests (SKIP_DOWNLOADER_TESTS is set)")
    def test_fetch(self):
        resp = Util.fetch("//google.com")
        self.assertTrue(len(resp) > 0)

    def test_convert_url(self):
        self.assertEqual(
            "wallpapers_net_some_category_html",
            Util.convert_to_filename("http://wallpapers.net/some-category.html"),
        )

    def test_get_size(self):
        self.assertEqual((32, 32), Util.get_size("test.jpg"))
        self.assertRaises(Exception, lambda: Util.get_size("fake_image.jpg"))

    def test_is_image(self):
        self.assertTrue(Util.is_image("test.jpg"))
        self.assertTrue(Util.is_image("test.jpg", check_contents=True))
        self.assertTrue(Util.is_image("fake_image.jpg"))
        self.assertFalse(Util.is_image("fake_image.jpg", check_contents=True))

    def test_is_animated_gif(self):
        self.assertFalse(Util.is_animated_gif("test.jpg"))
        self.assertTrue(Util.is_animated_gif("animated.gif"))
        self.assertFalse(Util.is_animated_gif("not-animated.gif"))

    @unittest.skipIf(os.getenv("SKIP_DOWNLOADER_TESTS"), "Skipping downloader tests (SKIP_DOWNLOADER_TESTS is set)")
    def test_is_dead_or_not_image(self):
        self.assertTrue(Util.is_dead_or_not_image(None))
        self.assertTrue(Util.is_dead_or_not_image("not a URL"))
        self.assertTrue(Util.is_dead_or_not_image("http://www.cnn.com/"))
        self.assertTrue(Util.is_dead_or_not_image("http://vrty.org/"))
        self.assertTrue(Util.is_dead_or_not_image("http://www.google.com/dejkjdrelkjflkrejfjre"))
        self.assertFalse(
            Util.is_dead_or_not_image(
                "https://farm8.staticflickr.com/7133/7527967878_85fea93129_o.jpg"
            )
        )
        self.assertFalse(
            Util.is_dead_or_not_image(
                "http://interfacelift.com/wallpaper/D98ef829/00899_rustedbolt_2560x1600.jpg"
            )
        )
        self.assertTrue(
            Util.is_dead_or_not_image("http://wallpapers.wallbase.cc/rozne/wallpaper-1227671.jpg")
        )
        self.assertTrue(
            Util.is_dead_or_not_image("http://ns223506.ovh.net/rozne/a1b2/wallpaper-1996019.png")
        )

    def test_debounce(self):
        """ Test that the increment function is being debounced.
        The counter should only be incremented once 10 seconds after the last call to the function """
        count = [0]

        @debounce(0.6)
        def increment():
            count[0] += 1

        self.assertTrue(count[0] == 0)
        increment()
        increment()
        time.sleep(0.4)
        self.assertTrue(count[0] == 0)
        increment()
        increment()
        increment()
        increment()
        self.assertTrue(count[0] == 0)
        time.sleep(0.7)
        self.assertTrue(count[0] == 1)

    def test_throttle_no_trailing(self):
        count = [0]

        @throttle(seconds=0.3)
        def increment():
            count[0] += 1

        self.assertTrue(count[0] == 0)
        increment()
        self.assertTrue(count[0] == 1)
        increment()
        self.assertTrue(count[0] == 1)
        time.sleep(0.2)
        increment()
        self.assertTrue(count[0] == 1)
        time.sleep(0.2)
        increment()
        self.assertTrue(count[0] == 2)
        increment()
        self.assertTrue(count[0] == 2)
        time.sleep(0.31)
        self.assertTrue(count[0] == 2)

    def test_throttle_with_trailing(self):
        count = [0]

        @throttle(seconds=0.3, trailing_call=True)
        def increment():
            count[0] += 1

        self.assertTrue(count[0] == 0)
        increment()
        self.assertTrue(count[0] == 1)
        increment()
        self.assertTrue(count[0] == 1)
        time.sleep(0.2)
        increment()
        self.assertTrue(count[0] == 1)
        time.sleep(0.2)
        increment()
        self.assertTrue(count[0] == 2)
        increment()
        self.assertTrue(count[0] == 2)
        time.sleep(0.31)
        self.assertTrue(count[0] == 3)

    def test_cache(self):
        @cache(ttl_seconds=10)
        def fib(n):
            return 1 if n <= 1 else fib(n - 1) + fib(n - 2)

        self.assertEqual(573147844013817084101, fib(100))


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os
import unittest

from tests.TestDownloader import test_download_one_for
from variety.plugins.builtin.downloaders.MediaRSSDownloader import MediaRSSDownloader
from variety.plugins.builtin.downloaders.MediaRSSSource import MediaRSSSource


@unittest.skipIf(os.getenv("SKIP_DOWNLOADER_TESTS"), "Skipping downloader tests (SKIP_DOWNLOADER_TESTS is set)")
class TestMediaRssDownloader(unittest.TestCase):
    def test_download_one(self):
        test_download_one_for(
            self,
            MediaRSSSource().create_downloader(
                "http://backend.deviantart.com/rss.xml?q=boost%3Apopular+leaves&type=deviation"
            ),
        )

    def test_validate_deviantart(self):
        self.assertTrue(
            MediaRSSDownloader.validate(
                "http://backend.deviantart.com/rss.xml?q=boost%3Apopular+leaves&type=deviation"
            )
        )

    def test_validate_non_media_rss(self):
        self.assertFalse(MediaRSSDownloader.validate("http://www.dnevnik.bg/rss/?page=index"))

    def test_validate_non_rss(self):
        self.assertFalse(MediaRSSDownloader.validate("http://google.com"))


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os
import unittest

from tests.TestDownloader import get_plugin_downloader, test_download_one_for


@unittest.skipIf(os.getenv("SKIP_DOWNLOADER_TESTS"), "Skipping downloader tests (SKIP_DOWNLOADER_TESTS is set)")
class TestBingDownloader(unittest.TestCase):
    def test_download_one(self):
        dl = get_plugin_downloader("BingDownloader")
        test_download_one_for(self, dl)

    def test_fill_queue(self):
        dl = get_plugin_downloader("BingDownloader")
        queue = dl.fill_queue()
        self.assertTrue(len(queue) > 0)


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE
import os
import os.path
import shutil
import unittest

from variety import Util
from variety.ImageFetcher import ImageFetcher


class TestImageFetcher(unittest.TestCase):
    @unittest.skipIf(os.getenv("SKIP_DOWNLOADER_TESTS"), "Skipping downloader tests (SKIP_DOWNLOADER_TESTS is set)")
    def test_fetch(self):
        target_folder = "/tmp/variety/ImageFetcher"
        shutil.rmtree(target_folder, ignore_errors=True)
        os.makedirs(target_folder)
        for url in [
            "https://w.wallhaven.cc/full/dg/wallhaven-dgeqoj.jpg",
            "http://unsplash.com/photos/7EqQ1s3wIAI/download",
        ]:
            f = ImageFetcher.fetch(url, target_folder, verbose=False)
            self.assertIsNotNone(f)
            self.assertTrue(os.path.isfile(f))
            self.assertTrue(Util.is_image(f, check_contents=False))
            self.assertTrue(Util.is_image(f, check_contents=True))
            self.assertNotEqual("download", f)

    def test_extract_from_cd(self):
        self.assertEqual(
            "img.jpg",
            ImageFetcher.extract_filename_from_content_disposition("attachment; filename=img.jpg"),
        )
        self.assertEqual(
            "img.jpg",
            ImageFetcher.extract_filename_from_content_disposition(
                "attachment; filename='img.jpg'"
            ),
        )
        self.assertEqual(
            "img.jpg",
            ImageFetcher.extract_filename_from_content_disposition(
                'attachment; filename="img.jpg"'
            ),
        )
        self.assertEqual(
            None, ImageFetcher.extract_filename_from_content_disposition("attachment; a=b")
        )

    def test_url_ok(self):
        self.assertFalse(ImageFetcher.url_ok("some garbage", False, ["flickr.com", "wallbase.cc"]))
        self.assertFalse(ImageFetcher.url_ok("some garbage", True, ["flickr.com", "wallbase.cc"]))
        self.assertFalse(ImageFetcher.url_ok("http://www.host.com/x/y/z", False, ["flickr.com"]))
        self.assertFalse(
            ImageFetcher.url_ok("http://cnn.com/x/y", True, ["flickr.com", "wallbase.cc"])
        )
        self.assertFalse(
            ImageFetcher.url_ok("http://somehost.com/x/y", True, ["", "flickr.com", "wallbase.cc"])
        )
        self.assertTrue(ImageFetcher.url_ok("http://www.host.com/x/y/z.jpg", False, ["flickr.com"]))
        self.assertTrue(
            ImageFetcher.url_ok("http://www.wallbase.cc/x/y/z", True, ["flickr.com", "wallbase.cc"])
        )
        self.assertTrue(
            ImageFetcher.url_ok("https://www.flickr.com/a", True, ["flickr.com", "wallbase.cc"])
        )


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE
import unittest

from tests import setup_test_logging
from variety.AttrDict import AttrDict

setup_test_logging()


class TestAttrDict(unittest.TestCase):
    def test_attr_dict(self):
        a = AttrDict({"a": {"b": 1}})
        self.assertFalse(bool(a.deep.inside))
        self.assertTrue(bool(a.a))
        self.assertEqual(1, a.a.b)
        a.l.k = 3
        self.assertEqual(3, a.l.k)
        a.f.g.h = 2
        self.assertEqual(2, a.f.g.h)
        a["x"]["y"]["z"] = 1
        self.assertEqual(1, a["x"]["y"]["z"])

        b = AttrDict(x=1, y=2)
        self.assertFalse(bool(b.deep.inside))
        self.assertEqual(1, b.x)
        self.assertEqual(2, b.y)

        b.c = {"z": 3}
        self.assertEqual(3, b.c.z)
        self.assertFalse(bool(b.c.dredrefre))


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE
import os
import tempfile
import unittest
from unittest.mock import MagicMock

from tests.TestDownloader import test_download_one_for
from variety.plugins.builtin.downloaders.WallhavenSource import WallhavenSource
from variety.Util import Util


@unittest.skipIf(os.getenv("SKIP_DOWNLOADER_TESTS"), "Skipping downloader tests (SKIP_DOWNLOADER_TESTS is set)")
class TestWallhavenDownloader(unittest.TestCase):
    def test_download_one(self):
        source = WallhavenSource()
        mock = MagicMock()
        mock.options.wallhaven_api_key = ""
        source.set_variety(mock)
        test_download_one_for(self, source.create_downloader("landscape"))

    def test_legacy_fallback_download_one(self):
        source = WallhavenSource()
        mock = MagicMock()
        mock.options.wallhaven_api_key = ""
        source.set_variety(mock)

        with tempfile.TemporaryDirectory() as tmpdir:
            dl = source.create_downloader("https://wallhaven.cc/user/lewdpatriot/favorites/935888")
            dl.update_download_folder(tmpdir)
            for _ in range(5):
                f = dl.download_one()
                if f and os.path.isfile(f) and Util.is_image(f, check_contents=True):
                    return
            self.fail("Tried download_one 5 times, all failed")

    def test_fill_queue(self):
        source = WallhavenSource()
        mock = MagicMock()
        mock.options.wallhaven_api_key = ""
        source.set_variety(mock)
        dl = source.create_downloader("nature")
        queue = dl.fill_queue()
        self.assertTrue(len(queue) > 0)


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os
import unittest

from tests.TestDownloader import test_download_one_for
from variety.AttrDict import AttrDict
from variety.plugins.builtin.downloaders.RedditDownloader import RedditDownloader
from variety.plugins.builtin.downloaders.RedditSource import RedditSource


@unittest.skipIf(os.getenv("SKIP_DOWNLOADER_TESTS"), "Skipping downloader tests (SKIP_DOWNLOADER_TESTS is set)")
class TestRedditDownloader(unittest.TestCase):
    def test_download_one(self):
        source = RedditSource()
        test_download_one_for(self, source.create_downloader("http://www.reddit.com/r/AutumnPorn/"))

    def test_build_json_url(self):
        self.assertEqual(
            "http://www.reddit.com/r/comics/.json?limit=100",
            RedditDownloader.build_json_url("http://www.reddit.com/r/comics/"),
        )

        self.assertEqual(
            "http://www.reddit.com/r/comics/top/.json?limit=100",
            RedditDownloader.build_json_url("http://www.reddit.com/r/comics/top/"),
        )

        self.assertEqual(
            "http://www.reddit.com/r/comics/top/.json?sort=top&t=week&limit=100",
            RedditDownloader.build_json_url("http://www.reddit.com/r/comics/top/?sort=top&t=week"),
        )

    def test_validate(self):
        parent = AttrDict()
        parent.options.safe_mode = True

        source = RedditSource()
        source.set_variety(parent)

        def _validate(url):
            return source.validate(url)[1] is None

        self.assertTrue(_validate("http://www.reddit.com/r/comics"))
        self.assertFalse(_validate("http://www.reddit.com/r/nsfw/"))

        parent.options.safe_mode = False
        self.assertTrue(_validate("http://www.reddit.com/r/comics"))
        self.assertTrue(_validate("http://www.reddit.com/r/nsfw/"))

        self.assertTrue(_validate("http://www.reddit.com/r/AutumnPorn/"))
        self.assertTrue(_validate("http://www.reddit.com/r/AutumnPorn/top?sort=top&t=month"))
        self.assertFalse(_validate("http://www.reddit.com/r/bestof/"))
        self.assertFalse(_validate("http://www.reddit.com/r/dhkjregfhjregfjfdrejh/"))
        self.assertFalse(_validate("http://www.notreddit.com/r/dhkjregfhjregfjfdrejh/"))


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE
import os
import shutil
import unittest

from jumble.Jumble import Jumble
from tests import setup_test_logging
from variety import Util
from variety.AttrDict import AttrDict

setup_test_logging()


def get_plugin_downloader(typename):
    p = Jumble(["variety/plugins/builtin"])
    p.load()
    plugin = p.get_plugins(typename=typename)[0]["plugin"]
    parent = AttrDict()
    parent.size_ok = lambda x, y: True
    plugin.set_variety(parent)
    return plugin


def test_download_one_for(test_case, dl):
    dl.target_folder = "/tmp/variety/%s" % dl.__class__.__name__
    shutil.rmtree(dl.target_folder, ignore_errors=True)
    for _ in range(5):
        f = dl.download_one()
        if f and os.path.isfile(f) and Util.is_image(f, check_contents=True):
            return
    test_case.fail("Tried download_one 5 times, all failed")


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os.path
import sys
import unittest

from jumble.IPlugin import IPlugin
from jumble.Jumble import Jumble
from variety.plugins.IQuoteSource import IQuoteSource

sys.path.insert(0, os.path.realpath(os.path.dirname(__file__)))


class P1(IPlugin):
    pass


class P2(IQuoteSource):
    pass


class TestJumble(unittest.TestCase):
    def test_load(self):
        p = Jumble(["variety/plugins/builtin"])
        p.load()

        # This is a rough count to make sure we can load multiple plugins correctly
        expected_plugins_count = 10
        self.assertGreaterEqual(len(p.get_plugins()), expected_plugins_count)
        self.assertGreaterEqual(len(p.get_plugins(IPlugin)), expected_plugins_count)

        self.assertEqual(1, len(p.get_plugins(name="Goodreads")))



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import unittest

from variety.VarietyWindow import VarietyWindow


class TestVarietyWindow(unittest.TestCase):
    def test_replace_clock_filter_offsets(self):
        f = "-fill '#DDDDDD' -annotate 0x0+[%HOFFSET+100]+[%VOFFSET+150] '%H:%M' -pointsize 50 -annotate 0x0+[%HOFFSET+100]+[%VOFFSET+100] '%A, %B %d'"
        ff = VarietyWindow.replace_clock_filter_offsets(f, 200, 3)
        expected = "-fill '#DDDDDD' -annotate 0x0+300+153 '%H:%M' -pointsize 50 -annotate 0x0+300+103 '%A, %B %d'"
        self.assertEqual(expected, ff)


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import os
import unittest

from tests.TestDownloader import test_download_one_for
from variety.plugins.builtin.downloaders.ArtStationSource import ArtStationSource


@unittest.skipIf(os.getenv("SKIP_DOWNLOADER_TESTS"), "Skipping downloader tests (SKIP_DOWNLOADER_TESTS is set)")
class TestArtStationDownloader(unittest.TestCase):
    def test_download_one(self):
        test_download_one_for(
            self,
            ArtStationSource().create_downloader("https://www.artstation.com/anubis1982918.rss"),
        )

    def test_validate(self):
        source = ArtStationSource()
        self.assertEqual(
            ("https://www.artstation.com/anubis1982918.rss", None),
            source.validate("https://www.artstation.com/anubis1982918.rss"),
        )
        self.assertEqual(
            ("https://www.artstation.com/anubis1982918.rss", None),
            source.validate("https://www.artstation.com/anubis1982918"),
        )
        self.assertEqual(
            ("https://www.artstation.com/anubis1982918.rss", None),
            source.validate("https://artstation.com/anubis1982918"),
        )
        self.assertEqual(
            ("https://www.artstation.com/anubis1982918.rss", None),
            source.validate("http://artstation.com/anubis1982918"),
        )
        self.assertEqual(
            ("https://www.artstation.com/anubis1982918.rss", None), source.validate("anubis1982918")
        )
        self.assertIsNotNone(source.validate("http://cnn.com")[1])


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# Copyright (c) 2025, James Lu <james@overdrivenetworks.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from setuptools import find_packages, setup

setup(
    packages=find_packages(exclude=['tests']),
    long_description="""
Variety is a wallpaper manager for Linux systems. It supports numerous desktops
and wallpaper sources, including local files and online services:
Wallhaven, Unsplash, and more.

Where supported, Variety sits as a tray icon to allow easy pausing and resuming.
Otherwise, its desktop entry menu provides a similar set of options.

Variety also includes a range of image effects, such as oil painting and blur,
as well as options to layer quotes and a clock onto the background.""",

    # FIXME: data_files is deprecated
    data_files=[("share/metainfo", ["variety.appdata.xml"])],

    package_data={
        'variety': ['data/**', 'locale/**'],
    },
    include_package_data=True,
)



#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import subprocess
import unittest


class TestPylint(unittest.TestCase):
    def test_project_errors_only(self):
        """run pylint in error only mode
        
        your code may well work even with pylint errors
        but have some unusual code"""
        return_code = subprocess.call(["pylint", "-E", "variety"])
        # not needed because nosetests displays pylint console output
        # self.assertEqual(return_code, 0)

    # un-comment the following for loads of diagnostics
    # ~ def test_project_full_report(self):
    # ~ '''Only for the brave


# ~
# ~ you will have to make judgement calls about your code standards
# ~ that differ from the norm'''
# ~ return_code = subprocess.call(["pylint", 'variety'])

if __name__ == "__main__":
    "you will get better results with nosetests"
    unittest.main()
